---
title: <span class="badge object-type-scalar"></span> TebibitsPerSecond
---
# <span class="badge object-type-scalar"></span> TebibitsPerSecond

Data rate: tebibits/sec

## Definition

```python
# Data rate: tebibits/sec
TebibitsPerSecond: typing.Literal["Tibits"] = "Tibits"
```
